@@ -1,7 +1,7 @@
 # SWAML <http://swaml.berlios.de/>
 # Semantic Web Archive of Mailing Lists
 #
-# Copyright (C) 2005-2006 Sergio Fdez
+# Copyright (C) 2005-2008 Sergio Fernández
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by the
@@ -15,9 +15,12 @@
 
 __author__       = 'Sergio Fdez <http://www.wikier.org/>'
 __contributors__ = ['Diego Berrueta <http://www.berrueta.net/>',
-                    'Jose Emilio Labra <http://www.di.uniovi.es/~labra/>']
-__copyright__    = 'Copyright 2005-2006, Sergio Fdez'
+                    'Jose Emilio Labra <http://www.di.uniovi.es/~labra/>',
+                    'Iván Frade <http://blog.ifrade.es/>',
+                    'Nacho Barrientos <http://criptonita.com/~nacho>']
+__copyright__    = 'Copyright 2005-2008, Sergio Fernández'
 __license__      = 'GNU General Public License'
-__version__      = '0.0.5'
+__version__      = '0.1.0'
+__date__         = "2008-07-25"
 __url__          = 'http://swaml.berlios.de/'
-__agent__        = 'http://swaml.berlios.de/doap.rdf'
+__agent__        = 'http://swaml.berlios.de/doap#swaml'
